package Net::DNS::Mailbox;

use strict;
use warnings;

our $VERSION = (qw$Id: Mailbox.pm 1910 2023-03-30 19:16:30Z willem $)[2];




use integer;
use Carp;

use base qw(Net::DNS::DomainName);



sub new {
	my $class = shift;
	local $_ = shift;
	croak 'undefined mail address' unless defined $_;

	s/^.*<//g;						# strip excess on left
	s/>.*$//g;						# strip excess on right
	s/^\@.+://;						# strip deprecated source route
	s/\\\./\\046/g;						# disguise escaped dots

	my ( $localpart, @domain ) = split /[@.]([^@;:"]*$)/;	# split on rightmost @
	s/\./\\046/g for $localpart ||= '';			# escape dots in local part

	return bless __PACKAGE__->SUPER::new( join '.', $localpart, @domain ), $class;
}



sub address {
	return unless defined wantarray;
	my @label = shift->label;
	local $_ = shift(@label) || return '<>';
	s/\\\\//g;						# delete escaped \
	s/^\\034(.*)\\034$/"$1"/;				# unescape enclosing quotes
	s/\\\d\d\d//g;						# delete non-printable
	s/\\\./\./g;						# unescape dots
	s/\\//g;						# delete escapes
	return $_ unless scalar(@label);
	return join '@', $_, join '.', @label;
}



package Net::DNS::Mailbox1035;		## no critic ProhibitMultiplePackages
our @ISA = qw(Net::DNS::Mailbox);

sub encode { return &Net::DNS::DomainName1035::encode; }


package Net::DNS::Mailbox2535;		## no critic ProhibitMultiplePackages
our @ISA = qw(Net::DNS::Mailbox);

sub encode { return &Net::DNS::DomainName2535::encode; }


1;
__END__




